<?php
// API doc : http://techbureau-api-document.readthedocs.io/ja/latest/public/2_individual/4_ticker.html
// API url : https://api.zaif.jp/api/1/ticker/{currency_pair}

// ticker api url
$zaif_api_url  = "https://api.zaif.jp/api/1/ticker/";

// proxy settings
$proxy      = "";
$proxy_port = "";

$currency_pairs = array(
     "bch_btc" ,"bch_jpy" ,"bitcrystals_btc"
    ,"bitcrystals_jpy" ,"btc_jpy" ,"cicc_btc"
    ,"cicc_jpy" ,"eth_btc" ,"eth_jpy"
    ,"fscc_btc" ,"fscc_jpy" ,"jpyz_jpy"
    ,"mona_btc" ,"mona_jpy" ,"ncxc_btc"
    ,"ncxc_jpy" ,"pepecash_btc" ,"pepecash_jpy"
    ,"sjcx_btc" ,"sjcx_jpy" ,"xcp_btc"
    ,"xcp_jpy" ,"xem_btc" ,"xem_jpy"
    ,"zaif_btc" ,"zaif_jpy"
);

if (!check_arguments($argc, $argv, $currency_pairs)) {
    usage();
    die(1);
}

// show currency pairs
if ($argv[1] == "list") {
    print("- currency_pairs -" . PHP_EOL);
    foreach ($currency_pairs as $value) {
        printf("%s" . PHP_EOL, $value);
    }
    exit(0);
}

if ($argv[1] != "all") {
    $currency_pairs = array($argv[1]);
}

$curl = curl_init();
if ($curl == FALSE) {
    fputs(STDERR, "[ERR] curl_init(): " . curl_error($curl) . PHP_EOL);
    die(1);
}

// curl set options
curl_setopt($curl, CURLOPT_RETURNTRANSFER, TRUE);
// set proxy server settings
if (!empty($proxy) && !empty($proxy_port)) {
    curl_setopt($curl, CURLOPT_HTTPPROXYTUNNEL, 1);
    curl_setopt($curl, CURLOPT_PROXY, $proxy . ":" . $proxy_port);
    curl_setopt($curl, CURLOPT_PROXYPORT, $proxy_port);
}

// call ticker api
foreach ($currency_pairs as $currency) {
    curl_setopt($curl, CURLOPT_URL, $zaif_api_url . $currency);
    $response = curl_exec($curl);
    if ($response == FALSE) {
        fputs(STDERR, "[ERR] curl_exec(): " . curl_error($curl) . PHP_EOL);
        die(1);
    }
    // json decode
    $json_decode = json_decode($response, true);
    if ($json_decode == NULL) {
        fputs(STDERR, "[ERR] json_decode(): " . json_last_error_msg() . PHP_EOL);
        die(1);
    }
//    print_r($json_decode);
    printf("* %s *" . PHP_EOL, $currency);
    printf("last  : %f" . PHP_EOL, $json_decode["last"]);
    printf("high  : %f" . PHP_EOL, $json_decode["high"]);
    printf("low   : %f" . PHP_EOL, $json_decode["low"]);
    printf("vwap  : %f" . PHP_EOL, $json_decode["vwap"]);
    printf("volume: %f" . PHP_EOL, $json_decode["volume"]);
    printf("bid   : %f" . PHP_EOL, $json_decode["bid"]);
    printf("ask   : %f" . PHP_EOL, $json_decode["ask"]);
    print(PHP_EOL);
}
curl_close($curl);

exit(0);

//------------------------------
// function
//------------------------------
function check_arguments($argc, $argv, $currency_pair) {
    if ($argc != 2) {
        return FALSE;
    }
    $opts = $currency_pair;
    array_push($opts, "all", "list");
    if (!in_array($argv[1], $opts)) {
        return FALSE;
    }
    return TRUE;
}

function usage() {
    fputs(STDERR,
        "Usage: php ticker OPTION" . PHP_EOL .
        "OPTION:" . PHP_EOL .
        "   all  : show all currency pair price" . PHP_EOL .
        "   list : show all currency pair code" . PHP_EOL .
        "   currency pair code : show specified currency pair" . PHP_EOL .
        "       e.g. php last_price btc_jpy" . PHP_EOL .
        PHP_EOL);
}
